#
# spec file for package httpie
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           httpie
Version:        1.0.3
Release:        lp151.2.3.1
Summary:        CLI, cURL-like tool for humans
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Utilities
URL:            https://httpie.org/
Source:         https://github.com/jakubroztocil/httpie/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        http.1
BuildRequires:  %{python_module Pygments >= 2.1.3}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest-httpbin}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.18.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pygments >= 2.1.3
Requires:       python-requests >= 2.18.4
Suggests:       python-argparse >= 1.2.1
Suggests:       python-colorama >= 0.2.4
Provides:       httpie
BuildArch:      noarch
%python_subpackages

%description
HTTPie consists of a single "http" command designed for debugging and
interaction with HTTP servers, RESTful APIs, and web services.

It allows for issuing arbitrary HTTP requests and displays colorized
responses.

%prep
%setup -q

#drop shebang
sed -i -e '/^#!\//, 1d' httpie/__main__.py

%build
export LC_CTYPE=en_US.UTF-8
%python_build

%install
export LC_CTYPE=en_US.UTF-8
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
install -D -m 0644 %{SOURCE1} %{buildroot}%{_mandir}/man1/http.1

%check
export LC_CTYPE=en_US.UTF-8
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} py.test-%{$python_version}

%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license LICENSE
%python3_only %{_bindir}/http
%{python_sitelib}/*
%{_mandir}/man1/http.1%{ext_man}

%changelog
* Tue Aug 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.0.3
  * Fix CVE-2019-10751 (HTTPie is volnerable to Open Redirect that
    allows an attacker to write an arbitrary file with supplied
    filename and content to the current directory, by redirecting
    a request from HTTP to a crafted URL pointing to a server in
    his or hers control.
* Sun Dec 16 2018 mardnh@gmx.de
- Add manpage
* Sat Dec 15 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from description.
* Wed Dec 12 2018 mardnh@gmx.de
- Cleanup package
- Run tests
- Update to version 1.0.2
  * Fixed tests for installation with pyOpenSSL.
  * Removed external URL calls from tests.
- Update to version 1.0.0
  * Added --style=auto which follows the terminal ANSI color styles.
  * Added support for selecting TLS 1.3 via --ssl=tls1.3
  * Added true/false as valid values for --verify
  * (in addition to yes/no) and the boolean value is case-insensitive.
  * Changed the default --style from solarized to auto
  * Fixed default headers being incorrectly case-sensitive.
  * Removed Python 2.6 support.
* Thu Aug 10 2017 mardnh@gmx.de
- Fix Url
- Update to version 0.9.8
  * Extended auth plugin API.
  * Added exit status code 7 for plugin errors.
  * Added support for curses-less Python installations.
  * Fixed REQUEST_ITEM arg incorrectly being reported as required.
  * Improved CTRL-C interrupt handling.
  * Added the standard exit status code 130 for keyboard interrupts.
- Update to version 0.9.5
  * Added Python 3 as a dependency for Homebrew installations to ensure some of
    the newer HTTP features work out of the box for macOS users (starting with
    HTTPie 0.9.4.).
  * Added the ability to unset a request header with Header:, and send an empty
    value with Header;.
  * Added --default-scheme <URL_SCHEME> to enable things like $ alias https=
    'http --default-scheme=https.
  * Added -I as a shortcut for --ignore-stdin.
  * Added fish shell completion (located in extras/httpie-completion.fish in
    the Github repo).
  * Updated requests to 2.10.0 so that SOCKS support can be added via pip
    install requests[socks].
  * Changed the default JSON Accept header from application/json to application
    /json, */*.
  * Changed the pre-processing of request HTTP headers so that any leading and
    trailing whitespace is removed.
- Update to version 0.9.4
  * Added Content-Type of files uploaded in multipart/form-data requests
  * Added --ssl=<PROTOCOL> to specify the desired SSL/TLS protocol version to
    use for HTTPS requests.
  * Added JSON detection with --json, -j to work around incorrect Content-Type
  * Added --all to show intermediate responses such as redirects (with --follow
    )
  * Added --history-print, -P WHAT to specify formatting of intermediate
    responses
  * Added --max-redirects=N (default 30)
  * Added -A as short name for --auth-type
  * Added -F as short name for --follow
  * Removed the implicit_content_type config option (use "default_options":
    ["--form"] instead)
  * Redirected stdout doesn't trigger an error anymore when --output FILE is
    set
  * Changed the default --style back to solarized for better support of light
    and dark terminals
  * Improved --debug output
  * Fixed --session when used with --download
  * Fixed --download to trim too long filenames before saving the file
  * Fixed the handling of Content-Type with multiple +subtype parts
  * Removed the XML formatter as the implementation suffered from multiple
    issues
- Update to version 0.9.3
  * Changed the default color --style from solarized to monokai
  * Added basic Bash autocomplete support (need to be installed manually)
  * Added request details to connection error messages
  * Fixed 'requests.packages.urllib3' has no attribute 'disable_warnings'
    errors that occurred in some installations
  * Fixed colors and formatting on Windows
  * Fixed --auth prompt on Windows
* Fri Sep 25 2015 robert.munteanu@gmail.com
- Add requirement for python-curses
* Mon Jul 20 2015 aloisio@gmx.com
- Fixed SLE11 build
* Tue May 19 2015 prusnak@opensuse.org
- updated to 0.9.2
* Sun Jun 15 2014 prusnak@opensuse.org
- created package (version 0.8.0)
